Compute parameters of the posterior distribution for the two-tap scenario with equal spatial variance
posterior_params_2Tap_EqVar.RdThe function computes parameters of the 2-dimensional posterior distrbution, namely, the posterior modes for both dimensions (corresponding to taps 1 and tap 2), the variance, and correlation. The code refers to the two-tap model with equal variance (spatial uncertainty) for both taps as described in Goldreich & Tong (2013), given in Formula A14.
Arguments
- x1m
measured/sensed or hypothetical position of tap 1 for which the likelihood (p given the other parameters) is computed
- x2m
measured/sensed or hypothetical position of tap 2
- time_t
speed prior (in units of space per time; given as a standard deviation)
- sigma_s
spatial uncertainty (given as a standard deviation) for the taps (same sd assumed for both positions)
- sigma_v
speed prior (in units of space per time; given as a standard deviation)